@@ -7,10 +7,11 @@ BEGIN{
 use strict;
 use warnings;
 package App::CSE;
-$App::CSE::VERSION = '0.009';
+$App::CSE::VERSION = '0.010';
 
 use Moose;
 use Class::Load;
+use Cwd;
 use App::CSE::Colorizer;
 use DateTime;
 use File::MimeInfo::Magic;
@@ -21,6 +22,8 @@ use String::CamelCase;
 use Path::Class::Dir;
 use File::stat;
 use Getopt::Long qw//;
+use Regexp::Assemble;
+use Text::Glob;
 use XML::LibXML;
 
 use Log::Log4perl qw/:easy/;
@@ -65,6 +68,8 @@ See L<App::CSE::Command::Help> For a description the available commands.
 
 =item Paging
 
+=item Ignoring files
+
 =item Works with Perl 5.8.8 up to 5.20
 
 =back
@@ -147,6 +152,10 @@ has 'index_meta' => ( is => 'ro', isa => 'HashRef[Str]', lazy_build => 1);
 # File utilities
 has 'xml_parser' => ( is => 'ro' , isa => 'XML::LibXML', lazy_build => 1);
 
+# Environment slurping
+has 'cseignore' => ( is => 'ro', isa => 'Maybe[Path::Class::File]', lazy_build => 1 );
+has 'ignore_reassembl' => ( is => 'ro', isa => 'Regexp::Assemble', lazy_build => 1);
+
 {# Singleton flavour
   my $instance;
   sub BUILD{
@@ -158,6 +167,32 @@ has 'xml_parser' => ( is => 'ro' , isa => 'XML::LibXML', lazy_build => 1);
   }
 }
 
+sub _build_cseignore{
+    my ($self) = @_;
+    my $file = Path::Class::Dir->new()->file('.cseignore');
+    unless( -e $file ){
+        return;
+    }
+    $LOGGER->info("Will ignore patterns from '$file'");
+    return $file;
+}
+
+sub _build_ignore_reassembl{
+    my ($self) = @_;
+    my $re = Regexp::Assemble->new();
+    if( my $cseignore = $self->cseignore() ){
+        my @lines = split(q/\n/ , $cseignore->slurp());
+        foreach my $line ( @lines ){
+            if( $line =~ /^\s*(?:#|$)/ ){
+                next;
+            }
+            $line =~ s/^\s*//; $line =~ s/\s*$//;
+            $re->add( Text::Glob::glob_to_regex_string( $line ) );
+        }
+    }
+    return $re;
+}
+
 sub _build_xml_parser{
   my ($self) = @_;
   return XML::LibXML->new();
@@ -341,13 +376,18 @@ sub is_file_valid{
     $opts = {};
   }
 
+  if( $self->ignore_reassembl()->match( $file_name ) ){
+      $LOGGER->trace("File $file_name is ignoreed. Skipping");
+      return $opts->{on_skip} ? &{$opts->{on_skip}}() : undef;
+  }
+
   if( $file_name =~ /(?:\/|^)\.[^\/\.]+/ ){
     $LOGGER->trace("File $file_name is hidden. Skipping");
     return $opts->{on_hidden} ? &{$opts->{on_hidden}}() : undef;
   }
 
   unless( -r $file_name ){
-    $LOGGER->trace("Cannot read $file_name. Skipping");
+    $LOGGER->warn("Cannot read $file_name. Skipping");
     return $opts->{on_unreadable} ? &{$opts->{on_unreadable}}() : undef;
   }
 
