@@ -1,5 +1,5 @@
 package App::CSE::Command::Index;
-$App::CSE::Command::Index::VERSION = '0.009';
+$App::CSE::Command::Index::VERSION = '0.010';
 use Moose;
 extends qw/App::CSE::Command/;
 with qw/App::CSE::Role::DirIndex/;
@@ -100,6 +100,10 @@ sub execute{
                                                     on_hidden => sub{
                                                       $File::Find::prune = 1;
                                                       return undef;
+                                                    },
+                                                    on_skip => sub{
+                                                      $File::Find::prune = 1;
+                                                      return undef;
                                                     }
                                                    });
       unless( $valid ){
